@@ -110,7 +110,14 @@ def build(path: str):
                 
 def publish(path: str):
     # Upload to PyPI.
-    if os.path.exists('.pypirc'):
+    ckpth = os.path.join(
+        os.environ['USERPROFILE'],
+        '.pypirc'
+    ) if platform.startswith('win') else os.path.join(
+        os.environ['HOME'],
+        '.pypirc'
+    )
+    if os.path.exists(ckpth):
         if platform.startswith('win'):
             os.chdir(os.environ['USERPROFILE'])
             pnam = f'py -m twine upload "{path}"'
@@ -121,13 +128,13 @@ def publish(path: str):
                 for line in p.stdout:
                     print(line, end='')
         else:
-            #os.chdir(os.environ['HOME'])
             print(
                 f'\n{61*"-"}\nWrite "python3 -m twine upload dist/*" '
                 f'for uploading to PyPI!\n{61*"-"}\n'
             )
     else:
         print('Please create token first!')
+    del ckpth
    
         
 def main():
